
dofile('worlds/common.lua')

--============================================================
-- global variables

description = ''
time_description = 0

last_load_or_save_time = 0

is_game_over = 0

black_sprite = 0

time_main_music = 0
time_quiet_music = 0

foundTramwayTicket = 0

fall_in_water_sprite = 0

is_player_in_water = false

sound = {splash=0, main_music=0, quiet_music=0}

is_night = false

--============================================================
--init/deinit

function lua_onInitGame()

	sound.splash = loadSound('sound/splash.wav')
	sound.main_music = loadSound('sound/start.ogg')
	sound.quiet_music = loadSound('sound/feuille.ogg')
	
	balloon = load2DSprite('images/balloon.png')
	black_sprite = load2DSprite('images/black.png')
	
	fall_in_water_sprite = load2DSprite('images/fall_in_water.png')
	
	model.delta_wing = load3DModel('models/obj_delta_wing/delta_wing.obj')
	
	time_main_music = getTime()
	time_quiet_music = getTime() + 120000 --120 seconds
	setPlayerPosition(0, 900, 0)
	callLoadGame()
end

function lua_onUninitGame()
	unload3DModel(model.delta_wing)
	unload2DSprite(black_sprite)
	unload2DSprite(balloon)
	unload2DSprite(fall_in_water_sprite)
end

--============================================================
-- main function

function lua_loop()
	
	clearBackground()
	if is_night then
		setFogColor(0,0,0)
	else
		setFogColor(180,200,255)
	end
	--setFogColor(100,128,255)
		
	--==============================
	-- play the music
	
	if getTime() > time_main_music then
		time_main_music = getTime() + 500000
		playSound(sound.main_music)
	end
	if getTime() > time_quiet_music then
		time_quiet_music = getTime() + 500000
		playSound(sound.quiet_music)
	end
	
	if getKey('j') then
		drawSpriteFullscreen(balloon)
	end
	
	if getKeyNoRepeat('a') then
		setEditorMode(not isEditorMode())
	end
	
	--==============================
	-- draw 3d world

	time1 = draw3DWorld()
	
	if not isEditorMode() then
		
		x, y, z = getPlayerPosition()
		
		-- fall into the water
		if y < -15.0 and not(getPlayerMovementType() == 2) then 
			setPlayerMovementFly()
		end
		if y < -0.0 and not is_player_in_water then
			playSound(sound.splash)
			is_player_in_water = true
		end
		
		-- come from the water
		if y > 0.0 and not(getPlayerMovementType() == 0) then 
			setPlayerMovementWalk()
		end
		if y > 0.0 and is_player_in_water then
			playSound(sound.splash)
			is_player_in_water = false
		end
		
		if getKey('l') then
			callLoadGame()	
		end
		
		-- flying
		if getKey('r') then
			speedx, speedy, speedz = getPlayerSpeed()
			setPlayerSpeed(speedx, 1.0, speedz)
		end
		
		--if getKey('ASCII:27') then
		--	quitGame()
		--end
		
		-- delta_wing
		local left_click, middle_click, right_click, mouse_pos_x, mouse_pos_y = getMouseInfos()
		if left_click then
			speedx, speedy, speedz = getPlayerSpeed()
			if speedy < -0.0 then
				setCurrentPosition(getPlayerPosition())
				local angle_x, angle_y, dist = getCameraAngleAndDistance()
				rotatePosition(0,angle_y,0)
				draw3DModel(model.delta_wing)
				if speedx > 0.0 then
					setPlayerSpeed(6.0, -0.2, speedz)
				else
					setPlayerSpeed(speedx, -0.2, speedz)
				end
			end
		end

		if getKey('b') and is_night == true then
			is_night = false
			changeConfigValueString("skybox_directory", "skyboxes/skybox_day")
			changeConfigValueString("player_model_directory", "models/obj_player_magician")
		end
		if getKey('n') and is_night == false then
			is_night = true
			changeConfigValueString("skybox_directory", "skyboxes/skybox_night")
			changeConfigValueString("player_model_directory", "models/obj_player_robot")
		end
		
		--if getKey('y')  then
		--	x, y, z = getPlayerPosition()
		--	startCubeCreation(x,y,z)
		--end
		
		if getKey('i') then
			local angle_x, angle_y, dist = getCameraAngleAndDistance()
			local x, y, z = cartesianCoordFromSphericalCoord(angle_x,angle_y, 15.0)
			local xpl, ypl, zpl = getPlayerPosition()
			removeCube(x+xpl,y+ypl,z+zpl)
		end
		
		local is_finished, x1,y1,z1,x2,y2,z2 = manageCubeCreation()
		
		if is_finished == 1 then
			createCube(x1,y1,z1,x2,y2,z2,2)
			is_finished = 0
		end
		
		if getKeyNoRepeat('u') then
			local x,y,z=getPlayerPosition()
			createObject(x,y+5,z,6)
			--setPlayerMovementFly()
		end
		--if getKey('u') then
		--	angle_x, angle_y, distance = getCameraAngleAndDistance()
		--	setCameraAngleAndDistance(angle_x, angle_y, distance+1)
		--end
	end
	
	--lua standard libraries test
	--print (math.cos(0.5).."-")
	
	--==============================
	-- draw 2d
	
	time2 = draw2DWorld()
	
	nb_visibles_spheres=0
	
	-- character text
	if text_balloon ~= '' then
		draw2DSprite(balloon, 10,10)
		drawText(text_balloon,40, 40)
	end
	
	-- contextual text
	if description ~= ''  then
		drawText(description, 10, 10)
		if getTime() > time_description then
			description = ''
		end
	end
	
	if is_player_in_water then
		setPlayerMovementNone()
		setColor(255,255,255,255)
		local win_width, win_height = getWindowSize()
		if not isEditorMode() then
			draw2DSprite(fall_in_water_sprite, win_width/2 - 128, win_height/2 - 128)
		end
		local px,py,pz = getPlayerPosition()
		setPlayerPosition(px, -10.0, pz)
		--drawTextCenter('Don\'t fall into the water ...')
		--drawText('Press Esc to quit, or "L" to \nreload from last saved sphere', width/2 - 200, height/2+50)
	end
	
	--local xpl,ypl,zpl = getPlayerPosition()
	--local cube_type, x_center,y_center,z_center, x_size,h_size,d_size = getCollidingCubeInfos(xpl,ypl-20,zpl)
	--drawText(cube_type..","..x_center..","..y_center..","..z_center..","..x_size..","..h_size..","..d_size, 10, 180)

	-- gameover display
	if is_game_over == 1 then
		setPlayerMovementNone()
		drawSpriteFullscreen(black_sprite)
		setColor(255,255,255,255)
		drawTextCenter('Game over')
		local width, height = getWindowSize()
		drawText('Press Esc to quit, or "L" to \nreload from last saved sphere', width/2 - 200, height/2+50)
	end	

	if not isEditorMode() then
		drawText('For main commands, press Esc. Additional test commands:\nu: shoot explosive sphere\ni: delete cube\nr: fly\nn/b: night robot / day magician', 10, 30)
	end
end

--============================================================
