
dofile('worlds/common.lua')

--============================================================
-- global variables

last_load_or_save_time = 0

foundTramwayTicket = 0

fall_in_water_sprite = 0

is_player_in_water = false

sound = {splash=0}

no_key = false

is_player_1 = true
time_player=0

wait_player = false
have_weapon = false

position_other_player = {x,y,z}

model_preloads = {}

--============================================================
--init/deinit

function lua_onInitGame()

	sound.splash = loadSound('sound/splash.wav')
	
	balloon = load2DSprite('images/balloon.png')
	
	magician_wins_sprite = load2DSprite('images/magician_wins.png')
	robot_wins_sprite = load2DSprite('images/robot_wins.png')
	
	model.delta_wing = load3DModel('models/obj_delta_wing/delta_wing.obj')
	
	model_preloads.model_magician_small = load3DModel('models/obj_player_magician_small/player_frame1.obj')
	model_preloads.model_robot_small = load3DModel('models/obj_player_robot_small/player_frame1.obj')
	
	position_other_player.x=0
	position_other_player.y=500
	position_other_player.z=-150
	setPlayerPosition(position_other_player.x, position_other_player.y,position_other_player.z)
	callLoadGame()
end

function lua_onUninitGame()
	unload3DModel(model.delta_wing)
	unload2DSprite(balloon)
	unload2DSprite(magician_wins_sprite)
	unload2DSprite(robot_wins_sprite)
	
	unload3DModel(model_preloads.model_magician_small)
	unload3DModel(model_preloads.model_robot_small)
end              

--============================================================
-- main function

function lua_loop()
	
	clearBackground()
	setFogColor(180,200,255)
		
	--==============================
	-- draw 3d world

	time1 = draw3DWorld()
	
	if is_player_1 then
		setCurrentPosition(position_other_player.x, position_other_player.y, position_other_player.z)
		draw3DModel(model_preloads.model_robot_small)
	else
		setCurrentPosition(position_other_player.x, position_other_player.y, position_other_player.z)
		draw3DModel(model_preloads.model_magician_small)
	end
	
	if getKeyNoRepeat('a') then
		setEditorMode(not isEditorMode())
	end
	
	if not isEditorMode() then
		
		x, y, z = getPlayerPosition()
		
		-- fall into the water
		if y < -0.0 and not is_player_in_water then
			playSound(sound.splash)
			is_player_in_water = true
		end
		
		-- delta_wing
		local left_click, middle_click, right_click, mouse_pos_x, mouse_pos_y = getMouseInfos()
		if left_click then
			speedx, speedy, speedz = getPlayerSpeed()
			if speedy < -0.0 then
				setCurrentPosition(getPlayerPosition())
				local angle_x, angle_y, dist = getCameraAngleAndDistance()
				rotatePosition(0,angle_y,0)
				draw3DModel(model.delta_wing)
				if speedx > 0.0 then
					setPlayerSpeed(6.0, -0.2, speedz)
				else
					setPlayerSpeed(speedx, -0.2, speedz)
				end
			end
		end

		--if getKey('y')  and have_weapon then
		--	local x, y, z = getPlayerPosition()
		--	createCube(x/10-3,y/10,z/10-3,x/10+4,y/10+7,z/10+4,2)
		--	setPlayerPosition(x,y+71,z)
		--	have_weapon = false
		--end
		
		local is_finished, x1,y1,z1,x2,y2,z2 = manageCubeCreation()
		
		if is_finished == 1 then
			createCube(x1,y1,z1,x2,y2,z2,2)
			is_finished = 0
		end
		
		if getKey('r') then
			no_key = true
		end
		
		if not wait_player then
			
			if no_key and getKey('r') and have_weapon then
				local x,y,z=getPlayerPosition()
				createObject(x,y+5,z,6)
				no_key = false
				have_weapon = false
			end
			
			if getTime() > time_player and is_player_in_water == false then
				if is_player_1 then
					is_player_1 = false
					changeConfigValueString("player_model_directory", "models/obj_player_robot")
				else
					is_player_1 = true
					changeConfigValueString("player_model_directory", "models/obj_player_magician")
				end
				
				local posttmpx, posttmpy, posttmpz = getPlayerPosition()
				setPlayerPosition(position_other_player.x,position_other_player.y,position_other_player.z)
				position_other_player.x = posttmpx
				position_other_player.y = posttmpy
				position_other_player.z = posttmpz
				no_key = false
				wait_player = true
				setPlayerMovementNone()
			end
		end
		
		local left_click, middle_click, right_click, mouse_x, mouse_y = getMouseInfos()
		if wait_player and left_click then
			setPlayerMovementWalk()
			time_player = getTime() + 10000
			wait_player = false
			have_weapon = true
		end
		
	end
	
	--==============================
	-- draw 2d
	
	time2 = draw2DWorld()
	
	if not is_player_in_water then
		local window_width, window_height = getWindowSize()
		if wait_player then
			drawText('New player, press left mouse button now', 20, window_height-60)
		else
			local remaining_time = time_player - getTime()
			local text_remaining_time = 'Remaining time current player: '..remaining_time
			drawText(text_remaining_time, 20, window_height-60)
			if remaining_time < 1000 then drawText('Next player, prepare yourself!', 20, window_height-30) end
		end
	end
	
	nb_visibles_spheres=0
	
	-- character text
	if text_balloon ~= '' then
		draw2DSprite(balloon, 10,10)
		drawText(text_balloon,40, 40)
	end
	
	if is_player_in_water then
		setPlayerMovementNone()
		setColor(255,255,255,255)
		local win_width, win_height = getWindowSize()
		if not isEditorMode() then
			if is_player_1 then
				draw2DSprite(robot_wins_sprite, win_width/2 - 128, win_height/2 - 128)
			else
				draw2DSprite(magician_wins_sprite, win_width/2 - 128, win_height/2 - 128)
			end
		end
		local px,py,pz = getPlayerPosition()
		setPlayerPosition(px, -10.0, pz)
	end
	
	if not isEditorMode() then
		drawText('For main commands, press Esc. Additional commands:\nR: shoot a sphere\n', 10, 30)
	end

end

--============================================================
